@@ -29,6 +29,9 @@ class Modes(Enum):
     ManualOn = 1
     Auto = 2
 
+    def __str__(self):
+        return self.name
+
 
 class SpeedLevels(Enum):
     """Speed levels enum"""
@@ -39,6 +42,9 @@ class SpeedLevels(Enum):
     AI = 3
     NotSet = -1
 
+    def __str__(self):
+        return self.name
+
 
 class InfoMessages(Enum):
     """Information messages enum"""
@@ -59,6 +65,9 @@ class InfoMessages(Enum):
     Unspecified = 132
     WARNING_LEVEL_IF_EQUAL_OR_GREATER_THAN_THIS_VALUE = 128
 
+    def __str__(self):
+        return self.name
+
 
 class ChlorineControlStatuses(Enum):
     """Chlorine control status enum"""
@@ -73,6 +82,9 @@ class ChlorineControlStatuses(Enum):
     VeryHigh = 6
     VeryVeryHigh = 7
 
+    def __str__(self):
+        return self.name
+
 
 class SetupFlags(IntFlag):
     """Setup flags bit masks"""
@@ -80,6 +92,9 @@ class SetupFlags(IntFlag):
     NoTimerModel = 1
     TimerMasterIsPresentInSystem = 2
 
+    def __str__(self):
+        return self.name
+
 
 class StateFlags(IntFlag):
     """State flags bit masks"""
@@ -93,6 +108,9 @@ class StateFlags(IntFlag):
     UserSettingsHasChanged = 0x40
     SanitisingUntilNextTimerTomorrow = 0x80
 
+    def __str__(self):
+        return self.name
+
 
 class PhControlTypes(Enum):
     """pH control types enum"""
@@ -101,6 +119,9 @@ class PhControlTypes(Enum):
     Manual = 1
     Automatic = 2
 
+    def __str__(self):
+        return self.name
+
 
 class ChlorineControlTypes(Enum):
     """Chlorine control types enum"""
@@ -109,6 +130,9 @@ class ChlorineControlTypes(Enum):
     Manual = 1
     Automatic = 2
 
+    def __str__(self):
+        return self.name
+
 
 class VolumeUnitsTypes(Enum):
     """Volume units enum"""
@@ -117,6 +141,9 @@ class VolumeUnitsTypes(Enum):
     UsGallons = 1
     ImperialGallons = 2
 
+    def __str__(self):
+        return self.name
+
 
 class CapabilitiesFlags(IntFlag):
     """Capabilities flags bit masks"""
@@ -138,6 +165,9 @@ class AcidDosingInhibitStatuses(Enum):
     InhibitedIndefinitely = 1
     InhibitedForAPeriod = 2
 
+    def __str__(self):
+        return self.name
+
 
 class TimerFlags(IntFlag):
     """Timer flags bit masks"""
